@@ -1,6 +1,10 @@
-#undef PACKAGE
-#undef VERSION
-#undef DATEVERSION
+#undef TD_PACKAGE
+#undef TD_PACKAGE_DIR
+#undef TD_PACKAGE_DATA_DIR
+#undef TD_PACKAGE_LOCALE_DIR
+#undef TD_PACKAGE_SOURCE_DIR
+#undef TD_VERSION
+#undef TD_DATEVERSION
 #undef PREFIX_WIDGET_CORE
 #undef PREFIX_WIDGET_PLUGINS
 #undef ENABLE_NLS
@@ -9,7 +13,3 @@
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
 #undef HAVE_LIBSM
-#undef PACKAGE_LOCALE_DIR
-#undef PACKAGE_DATA_DIR
-#undef PACKAGE_SOURCE_DIR
-#undef PACKAGE_PLUGINS_DIR
