@@ -1,11 +1,11 @@
 /*****************************************************************************/
-/* td_about.c : Objet Gtk+
- * td_about.c : Gtk+ object
+/*** td_about.c : Objet Gtk+
+ *** td_about.c : Gtk+ object
  *
  *
  * ToutDoux : Chtit gestionnaire de projet - A littl' project manager
- * Copyright (c) 2000 Philippe Roy
- * Auteur - Author : Philippe Roy <ph_roy@yahoo.com>
+ * Copyright (c) 2000-2001 Philippe Roy
+ * Auteur - Author : Philippe Roy <ph_roy@toutdoux.org>
  *
  *
  * Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier
@@ -47,14 +47,13 @@
 #include <sys/stat.h>
 
 #include "commons.h"
-
+#include "gtdk.h"
 #include "td_app.h"
-
+#include "td_mod.h"
 #include "td_about.h"
 
-
 /*****************************************************************************/
-/* Arguments */
+/*** Arguments */
 /*****************************************************************************/
 static GtkObjectClass *parent_class = NULL;
 
@@ -63,7 +62,6 @@ enum {
   ARG_NAME,
   ARG_TYPE,
   ARG_VERSION,
-  ARG_BLURB,
   ARG_AUTHORS,
   ARG_HELP,
   ARG_CATEGORY1,
@@ -76,7 +74,7 @@ enum {
   ARG_WEB,
 };
 
-void td_about_set_name (TdAbout *about, gchar *name)
+static void td_about_set_name (TdAbout *about, gchar *name)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -84,7 +82,7 @@ void td_about_set_name (TdAbout *about, gchar *name)
     about->name = name;
 }
 
-void td_about_set_type (TdAbout *about, gchar *type)
+static void td_about_set_type (TdAbout *about, gchar *type)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -92,7 +90,7 @@ void td_about_set_type (TdAbout *about, gchar *type)
     about->type = type;
 }
 
-void td_about_set_version (TdAbout *about, gchar *version)
+static void td_about_set_version (TdAbout *about, gchar *version)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -100,15 +98,7 @@ void td_about_set_version (TdAbout *about, gchar *version)
     about->version = version;
 }
 
-void td_about_set_blurb (TdAbout *about, gchar *blurb)
-{
-  g_return_if_fail (about != NULL);
-  g_return_if_fail (TD_IS_ABOUT (about));
-  if (about->blurb != blurb)
-    about->blurb = blurb;
-}
-
-void td_about_set_authors (TdAbout *about, gchar *authors)
+static void td_about_set_authors (TdAbout *about, gchar *authors)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -116,7 +106,7 @@ void td_about_set_authors (TdAbout *about, gchar *authors)
     about->authors = authors;
 }
 
-void td_about_set_help (TdAbout *about, gchar *help)
+static void td_about_set_help (TdAbout *about, gchar *help)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -124,7 +114,7 @@ void td_about_set_help (TdAbout *about, gchar *help)
     about->help = help;
 }
 
-void td_about_set_category1 (TdAbout *about, gchar *category1)
+static void td_about_set_category1 (TdAbout *about, gchar *category1)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -132,7 +122,7 @@ void td_about_set_category1 (TdAbout *about, gchar *category1)
     about->category1 = category1;
 }
 
-void td_about_set_category2 (TdAbout *about, gchar *category2)
+static void td_about_set_category2 (TdAbout *about, gchar *category2)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -140,7 +130,7 @@ void td_about_set_category2 (TdAbout *about, gchar *category2)
     about->category2 = category2;
 }
 
-void td_about_set_category3 (TdAbout *about, gchar *category3)
+static void td_about_set_category3 (TdAbout *about, gchar *category3)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -148,7 +138,7 @@ void td_about_set_category3 (TdAbout *about, gchar *category3)
     about->category3 = category3;
 }
 
-void td_about_set_copyright (TdAbout *about, gchar *copyright)
+static void td_about_set_copyright (TdAbout *about, gchar *copyright)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -156,7 +146,7 @@ void td_about_set_copyright (TdAbout *about, gchar *copyright)
     about->copyright = copyright;
 }
 
-void td_about_set_license (TdAbout *about, gchar *license)
+static void td_about_set_license (TdAbout *about, gchar *license)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -164,7 +154,7 @@ void td_about_set_license (TdAbout *about, gchar *license)
     about->license = license;
 }
 
-void td_about_set_icon (TdAbout *about, gchar *icon)
+static void td_about_set_icon (TdAbout *about, gchar *icon)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -172,7 +162,7 @@ void td_about_set_icon (TdAbout *about, gchar *icon)
     about->icon = icon;
 }
 
-void td_about_set_logo (TdAbout *about, gchar *logo)
+static void td_about_set_logo (TdAbout *about, gchar *logo)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -180,7 +170,7 @@ void td_about_set_logo (TdAbout *about, gchar *logo)
     about->logo = logo;
 }
 
-void td_about_set_web (TdAbout *about, gchar *web)
+static void td_about_set_web (TdAbout *about, gchar *web)
 {
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
@@ -203,9 +193,6 @@ static void td_about_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
     case ARG_VERSION:
       td_about_set_version (about, GTK_VALUE_STRING (*arg));
       break;
-    case ARG_BLURB:
-      td_about_set_blurb (about, GTK_VALUE_STRING (*arg));
-      break;
     case ARG_AUTHORS:
       td_about_set_authors (about, GTK_VALUE_STRING (*arg));
       break;
@@ -256,9 +243,6 @@ static void td_about_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
     case ARG_VERSION:
       GTK_VALUE_STRING (*arg) = about->version;
       break;
-    case ARG_BLURB:
-      GTK_VALUE_STRING (*arg) = about->blurb;
-      break;
     case ARG_AUTHORS:
       GTK_VALUE_STRING (*arg) = about->authors;
       break;
@@ -295,16 +279,15 @@ static void td_about_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
     }
 }
 
+/*****************************************************************************/
+/*** Initialisation */
+/*****************************************************************************/
 
-/*****************************************************************************/
-/* Initialisation */
-/*****************************************************************************/
 static void td_about_init (TdAbout *about)
 {
   about->name = NULL;
   about->type = NULL;
   about->version = NULL;
-  about->blurb = NULL;
   about->authors = NULL;
   about->help = NULL;
   about->category1 = NULL;
@@ -325,7 +308,6 @@ static void td_about_class_init (TdAboutClass *klass)
   gtk_object_add_arg_type ("TdAbout::name", GTK_TYPE_STRING, GTK_ARG_READWRITE, ARG_NAME);
   gtk_object_add_arg_type ("TdAbout::type", GTK_TYPE_STRING, GTK_ARG_READWRITE, ARG_TYPE);
   gtk_object_add_arg_type ("TdAbout::version", GTK_TYPE_STRING, GTK_ARG_READWRITE, ARG_VERSION);
-  gtk_object_add_arg_type ("TdAbout::blurb", GTK_TYPE_STRING, GTK_ARG_READWRITE, ARG_BLURB);
   gtk_object_add_arg_type ("TdAbout::authors", GTK_TYPE_STRING, GTK_ARG_READWRITE, ARG_AUTHORS);
   gtk_object_add_arg_type ("TdAbout::help", GTK_TYPE_STRING, GTK_ARG_READWRITE, ARG_HELP);
   gtk_object_add_arg_type ("TdAbout::category1", GTK_TYPE_STRING, GTK_ARG_READWRITE, ARG_CATEGORY1);
@@ -358,20 +340,34 @@ GtkType td_about_get_type (void)
   return about_type;
 }
 
+/**
+ * td_about_new:
+ * 
+ * fr: Cr une nouvelle description
+ *
+ * en: Creates a new description
+ * 
+ * Return value: description
+ **/
+
 GtkObject *td_about_new (void)
 {
-  return GTK_OBJECT (gtk_type_new (td_about_get_type ()));
+  return GTK_OBJECT (gtk_type_new (td_about_get_type()));
 }
 
-
 /*****************************************************************************/
-/* Affectations */
+/*** Commandes - Commands */
 /*****************************************************************************/
 
+/**
+ * td_about_show:
+ * @about: td_about object
+ * 
+ * fr: Affiche la fentre  propos 
+ *
+ * en: Displays the about window
+ **/
 
-/*****************************************************************************/
-/* Commandes */
-/*****************************************************************************/
 void td_about_show (TdAbout *about)
 {
   GtkWidget *window;
@@ -382,7 +378,6 @@ void td_about_show (TdAbout *about)
   GtkWidget *label1 = NULL;
   GtkWidget *label2;
   GtkWidget *label3;
-  GtkWidget *entry1;
   GtkWidget *frame1;
   GtkWidget *scrolledwindow1;
   GtkWidget *text1;
@@ -393,15 +388,15 @@ void td_about_show (TdAbout *about)
   GtkWidget *href1;
   GdkFont *font = NULL;
   int txt_long;
+  GtkWidget *box_tmp = NULL;
   g_return_if_fail (about != NULL);
   g_return_if_fail (TD_IS_ABOUT (about));
 
-  /* Fentre */
+  /*** Fentre - Window */
   window = gtk_window_new (GTK_WINDOW_DIALOG);
-  txt_tampon = g_strdup_printf ("ToutDoux : %s" , _("About plug-in"));
-  gtk_window_set_title (GTK_WINDOW (window), txt_tampon);
+  gtdk_window_set_title (GTK_WINDOW (window), g_strdup_printf ("%s : %s", about->name, _("About")), TD_WINDOW_TYPE_TOOL);
   gtk_window_set_policy (GTK_WINDOW (window), FALSE, FALSE, FALSE);
-  eventbox1 = gtk_event_box_new ();
+  eventbox1 = gtk_event_box_new();
   gtk_widget_show (eventbox1);
   gtk_container_add (GTK_CONTAINER (window), eventbox1);
   viewport2 = gtk_viewport_new (NULL, NULL);
@@ -411,7 +406,7 @@ void td_about_show (TdAbout *about)
   gtk_widget_show (vbox1);
   gtk_container_add (GTK_CONTAINER (viewport2), vbox1);
 
-  /* Titre */
+  /*** Titre - Title */
   viewport1 = gtk_viewport_new (NULL, NULL);
   gtk_widget_show (viewport1);
   gtk_box_pack_start (GTK_BOX (vbox1), viewport1, FALSE, FALSE, 0);
@@ -422,39 +417,60 @@ void td_about_show (TdAbout *about)
   gtk_container_add (GTK_CONTAINER (viewport1), label1);
   font = label1->style->font;
   txt_long = gdk_string_width (font, txt_tampon);
-  gtk_widget_set_usize (label1, txt_long+5, -1);
+  gtk_widget_set_usize (label1, txt_long+10, -1);
+
+  /*** License - Licence */
+  box_tmp = gtk_vbox_new (FALSE, 0);
+  gtk_widget_show (box_tmp);
+  gtk_container_set_border_width (GTK_CONTAINER (box_tmp), 5);
+  gtk_box_pack_start (GTK_BOX (vbox1), box_tmp, FALSE, TRUE, 0);
   txt_tampon = g_strdup_printf ("%s", about->copyright);
   label2 = gtk_label_new (txt_tampon);
   gtk_widget_show (label2);
-  gtk_box_pack_start (GTK_BOX (vbox1), label2, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (box_tmp), label2, FALSE, TRUE, 0);
   font = label2->style->font;
   txt_long = gdk_string_width (font, about->copyright);
-  gtk_widget_set_usize (label2, txt_long+5, -1);
+  gtk_widget_set_usize (label2, txt_long+10, -1);
   txt_tampon = g_strdup_printf ("%s", about->license);
   label3 = gtk_label_new (txt_tampon);
   gtk_widget_show (label3);
-  gtk_box_pack_start (GTK_BOX (vbox1), label3, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (box_tmp), label3, FALSE, TRUE, 0);
   font = label3->style->font;
   txt_long = gdk_string_width (font, about->license);
-  gtk_widget_set_usize (label3, txt_long+5, -1);
+  gtk_widget_set_usize (label3, txt_long+10, -1);
 
-  /* Blurb */
-  entry1 = gtk_entry_new ();
-  gtk_widget_show (entry1);
-  gtk_box_pack_start (GTK_BOX (vbox1), entry1, FALSE, TRUE, 0);
-  gtk_entry_set_editable (GTK_ENTRY (entry1), FALSE);
-  gtk_entry_set_text (GTK_ENTRY (entry1), about->blurb);
-  font = entry1->style->font;
-  txt_long = gdk_string_width (font, about->blurb);
-  gtk_widget_set_usize (entry1, txt_long+5, -1);
+  /*** Description */
+  frame2 = gtk_frame_new (_("Description"));
+  gtk_widget_show (frame2);
+  gtk_container_set_border_width (GTK_CONTAINER (frame2), 5);
+  gtk_box_pack_start (GTK_BOX (vbox1), frame2, TRUE, TRUE, 0);
+  box_tmp = gtk_vbox_new (FALSE, 0);
+  gtk_widget_show (box_tmp);
+  gtk_container_set_border_width (GTK_CONTAINER (box_tmp), 5);
+  gtk_container_add (GTK_CONTAINER (frame2), box_tmp);
+  scrolledwindow2 = gtk_scrolled_window_new (NULL, NULL);
+  gtk_widget_show (scrolledwindow2);
+  gtk_container_add (GTK_CONTAINER (box_tmp), scrolledwindow2);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow2), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  text2 = gtk_text_new (NULL, NULL);
+  gtk_widget_show (text2);
+  gtk_container_add (GTK_CONTAINER (scrolledwindow2), text2);
+  gtk_widget_realize (text2);
+  if ((about->help) && (strcmp (about->help, "(null)")))
+    gtk_text_insert (GTK_TEXT (text2), NULL, NULL, NULL, about->help, -2);
 
-  /* Auteurs */
+  /*** Auteurs - Authors */
   frame1 = gtk_frame_new (_("Authors"));
   gtk_widget_show (frame1);
+  gtk_container_set_border_width (GTK_CONTAINER (frame1), 5);
   gtk_box_pack_start (GTK_BOX (vbox1), frame1, TRUE, TRUE, 0);
+  box_tmp = gtk_vbox_new (FALSE, 0);
+  gtk_widget_show (box_tmp);
+  gtk_container_set_border_width (GTK_CONTAINER (box_tmp), 5);
+  gtk_container_add (GTK_CONTAINER (frame1), box_tmp);
   scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
   gtk_widget_show (scrolledwindow1);
-  gtk_container_add (GTK_CONTAINER (frame1), scrolledwindow1);
+  gtk_container_add (GTK_CONTAINER (box_tmp), scrolledwindow1);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   text1 = gtk_text_new (NULL, NULL);
   gtk_widget_show (text1);
@@ -462,31 +478,15 @@ void td_about_show (TdAbout *about)
   gtk_widget_realize (text1);
   gtk_text_insert (GTK_TEXT (text1), NULL, NULL, NULL, about->authors, -2);
 
-  /* Aide */
-  frame2 = gtk_frame_new (_("Help"));
-  gtk_widget_show (frame2);
-  gtk_box_pack_start (GTK_BOX (vbox1), frame2, TRUE, TRUE, 0);
-  scrolledwindow2 = gtk_scrolled_window_new (NULL, NULL);
-  gtk_widget_show (scrolledwindow2);
-  gtk_container_add (GTK_CONTAINER (frame2), scrolledwindow2);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow2), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  text2 = gtk_text_new (NULL, NULL);
-  gtk_widget_show (text2);
-  gtk_container_add (GTK_CONTAINER (scrolledwindow2), text2);
-  gtk_widget_realize (text2);
-  if (strcmp (about->help, "(null)"))
-    gtk_text_insert (GTK_TEXT (text2), NULL, NULL, NULL, about->help, -2);
-
-  /* Site web */
-  if (strcmp (about->web, "(null)"))
+  /*** Site web - Web site */
+  if ((about->web) && (strcmp (about->web, "(null)")))
     {
-      href1 = gnome_href_new (about->web, about->web);
+      href1 = gtdk_button_href (about->web, NULL);
       gtk_widget_show (href1);
       gtk_box_pack_start (GTK_BOX (vbox1), href1, FALSE, FALSE, 0);
-      gtk_misc_set_padding (GTK_MISC (label3), 5, 0);
     }
 
-  /* Appels */
+  /*** Appels - Calls */
   gtk_widget_realize (window);
   gdk_window_set_cursor (window->window, gdk_cursor_new (GDK_ARROW));
   gtk_signal_connect_object (GTK_OBJECT (window), "delete_event", GTK_SIGNAL_FUNC (gtk_widget_destroy), GTK_OBJECT (window));
@@ -495,8 +495,20 @@ void td_about_show (TdAbout *about)
 }
 
 /*****************************************************************************/
-/* Fichier */
+/*** Fichier - File */
 /*****************************************************************************/
+
+/**
+ * td_about_get:
+ * @file: file location of plug-in
+ * 
+ * fr: Retourne l'objet td_about du greffon
+ *
+ * en: Return td_about object of the plug-in
+ * 
+ * Return value: td_about object
+ **/
+
 TdAbout *td_about_get (gchar *file)
 {
   TdAbout *ret;
@@ -505,32 +517,50 @@ TdAbout *td_about_get (gchar *file)
   plugins_tmp = dlopen (file, RTLD_LAZY);
   if (dlerror() !=NULL)
     {
-      td_palette_message (_("Loading plug-in"), g_strdup_printf (_("Loading plug-in : file '%s' unreadable"), file), "failed");
+      td_app_message (_("Loading plug-in"), g_strdup_printf (_("Loading plug-in : file '%s' unreadable"), file), TD_MSG_FAILED);
       return NULL;
     }
-  (gpointer*) symbol = td_dlsym (plugins_tmp, "", file, "plugins_about_def");
-  ret = symbol ();
+  (gpointer*) symbol = td_dlsym (plugins_tmp, "", file, "plugins_about_def", TRUE);
+  ret = symbol();
+  /* dlclose (plugins_tmp); */
   return ret;
 }
 
+/**
+ * td_about_filelist:
+ * @directory: directory location of plug-ins
+ * @type: type of plug-ins
+ * 
+ * fr: Retourne la liste des greffons du rpertoire
+ *
+ * en: Return the plug-in lis tof the directory
+ * 
+ * Return value: list
+ **/
+
 GList *td_about_filelist (gchar *directory, gchar *type)
 {
-  /* Little source reused : gnumeric/src/plugins.c : Author: Tom Dyas (tdyas@romulus.rutgers.edu) */
+  /*** THANKS: little source reused from
+       File: gnumeric/src/plugins.c
+       Author: Tom Dyas <tdyas@romulus.rutgers.edu> */
+
   TdAbout *about_plugins;
   GList *ret = NULL;
   DIR *d;
   struct dirent *e;
-
-  /* Fichiers */
+  if (!directory)
+    directory = TD_PACKAGE_PLUGINS_DIR;
+    
+  /*** Fichiers - File */
   if ((d = opendir (directory)) == NULL)
     {
-      td_palette_message (_("Reading plug-ins's directory"), _("Reading plug-ins's directory : directory unreadable"), "failed");
+      td_app_message (_("Reading plug-ins's directory"), _("Reading plug-ins's directory : directory unreadable"), TD_MSG_FAILED);
       return NULL; 
     }
   while ((e = readdir (d)) != NULL)
     if (strncmp (e->d_name + strlen (e->d_name) - 3, ".so", 3) == 0)
       {
-	/* Avec type */
+	/*** Avec type - With type */
 	if (type)
 	  {
 	    about_plugins = td_about_get (g_strconcat (directory, e->d_name, NULL));
@@ -541,7 +571,7 @@ GList *td_about_filelist (gchar *directory, gchar *type)
 		gtk_object_destroy (GTK_OBJECT (about_plugins));
 	      }
 	  }
-	/* Sans type */
+	/*** Sans type - Without type */
 	else
 	  {
 	    about_plugins = td_about_get (g_strconcat (directory, e->d_name, NULL));
@@ -556,6 +586,17 @@ GList *td_about_filelist (gchar *directory, gchar *type)
   return ret;
 }
 
+/**
+ * td_about_categorytree:
+ * @ctree: ctree widget
+ * @plugins_list: td_about list of plug-ins
+ * @file_list: file location of plug-ins
+ * 
+ * fr: Construit l'arbre des catgories des greffons
+ *
+ * en: Build the category tree of plug-ins
+ **/
+
 void td_about_categorytree (GtkCTree *ctree, GList *plugins_list, GList *file_list)
 {
   gchar *txt[2];
@@ -570,13 +611,13 @@ void td_about_categorytree (GtkCTree *ctree, GList *plugins_list, GList *file_li
   guint8 spacing_tampon;
   int nb_categorie_greffon;
 
-  /* Recherche d'une branche similaire */
+  /*** Recherche d'une branche similaire - Searching a similar branch */
   for (i=0; i<g_list_length (plugins_list); i++)
     {
       if (!strcmp (TD_ABOUT (g_list_nth_data (plugins_list, i))->category1, "(null)"))
 	continue;
 
-      /* Scan niveau 1 */
+      /*** Scan niveau 1 - Scan level 1 */
       existe = FALSE;
       node1 = gtk_ctree_node_nth (GTK_CTREE(ctree), 0);
       while ((node1) && (!existe))
@@ -593,7 +634,7 @@ void td_about_categorytree (GtkCTree *ctree, GList *plugins_list, GList *file_li
 	      existe = TRUE;
 	}
 
-      /* Cration niveau 1 */
+      /*** Cration niveau 1 - Creating level 1 */
       if (!existe)
 	{
 	  txt[0] = TD_ABOUT (g_list_nth_data (plugins_list, i))->category1;
@@ -624,7 +665,7 @@ void td_about_categorytree (GtkCTree *ctree, GList *plugins_list, GList *file_li
 	  continue;
 	}
 
-      /* Scan niveau 2 */
+      /*** Scan niveau 2 - Scan level 2 */
       existe = FALSE;
       gtk_ctree_collapse(GTK_CTREE (ctree), node1);
       if (GTK_CTREE_ROW (node1)->children)
@@ -645,7 +686,7 @@ void td_about_categorytree (GtkCTree *ctree, GList *plugins_list, GList *file_li
 	    existe = TRUE;
 	}
 
-      /* Cration niveau 2 */
+      /*** Cration niveau 2 - Creation level 2 */
       if (!existe)
 	{
 	  txt[0] = TD_ABOUT (g_list_nth_data (plugins_list, i))->category2;
@@ -665,7 +706,7 @@ void td_about_categorytree (GtkCTree *ctree, GList *plugins_list, GList *file_li
 	  continue;
 	}
 
-      /* Scan niveau 3 */
+      /*** Scan niveau 3 - Scan level 3 */
       existe = FALSE;
       gtk_ctree_collapse (GTK_CTREE (ctree), node1);
       if (GTK_CTREE_ROW (node2)->children)
@@ -686,7 +727,7 @@ void td_about_categorytree (GtkCTree *ctree, GList *plugins_list, GList *file_li
 	    existe = TRUE;
 	}
 
-      /* Cration niveau 2 */
+      /*** Cration niveau 2 - Creation level 2 */
       if (!existe)
 	{
 	  txt[0] = TD_ABOUT (g_list_nth_data (plugins_list, i))->category3;
